# Brevitas Examples

This folder contains various sets of examples:
- `bnn_pynq`: Simple QAT training examples at 1/2/4 bits targeting deployment with FINN.
- `imagenet_classification`: PTQ examples and pretrained 4b QAT models for classification over ImageNet.
- `speech_to_text`: pretrained 8b QAT MelGAN Vocoder, to insert in a text to speech pipeline.
- `super_resolution`: pretrained 8b QAT models trained to increase the resolution of RGB images with accumulator-aware quantization (A2Q).
- `text_to_speech`: pretrained 8b QAT QuartzNet for ASR.
